@@ -79,9 +79,11 @@ class FaceAnalyzer:
         """
         Converts the face vectros to TEXTA format.
         """
+        facts = []
         for face_vector in face_vectors:
             vector_fact = {self.es_name_field: name, self.es_vector_field: face_vector.tolist()}
-            yield vector_fact
+            facts.append(vector_fact)
+        return facts
 
 
     def add_photo(self, file_path, name="UNKOWN"):
@@ -96,12 +98,14 @@ class FaceAnalyzer:
         if face_vectors:
             vector_facts = self.vectors_to_facts(face_vectors, name)
             try:
-                doc = {self.es_nested_field_name: list(vector_facts)}
-                self.es.index(index=self.es_index, body=doc)
-                return True
+                # index each vector as a separate document
+                for vector_fact in vector_facts:
+                    doc = {self.es_nested_field_name: [vector_fact]}
+                    self.es.index(index=self.es_index, body=doc)
+                return vector_facts
             except Exception as e:
                 self.logger.error(f"Error analyzing face vectors: {e}")
-                return False
+                return []
 
 
     def analyze_photo(self, file_path, score=1.93):
@@ -126,8 +130,7 @@ class FaceAnalyzer:
                 for hit in result["hits"]["hits"]:
                     if self.es_nested_field_name in hit["_source"]:
                         for hit_fact in hit["_source"][self.es_nested_field_name]:
-                            # remove vector from fact
-                            del hit_fact["vector"]
+                            hit_fact["score"] = hit["_score"]
                             combined_hits.append(hit_fact)
             return combined_hits
         except Exception as e:
